IntentCallHostEvent class final

Event emitted by IntentCallFlutterHost while dispatching pending work.

Constructors

IntentCallHostEvent({required IntentCallHostEventKind kind, required IntentCallDrainTrigger trigger, IntentCallInvocationEnvelope? envelope, AgentResult? result, List<AgentResult> results = const <AgentResult>[], Object? error, StackTrace? stackTrace})
const

Properties

envelope → IntentCallInvocationEnvelope?
final
error → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
kind → IntentCallHostEventKind
final
result → AgentResult?
final
results → List<AgentResult>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
final
trigger → IntentCallDrainTrigger
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited