IntentCallPendingInvocations class final

Constructors

IntentCallPendingInvocations({MethodChannel channel = const MethodChannel('intentcall_platform/invocations')})
const

Properties

channel MethodChannel
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
takePending() Future<List<IntentCallInvocationEnvelope>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited