IntentCallFlutterHost class final

Constructors

IntentCallFlutterHost.bindRegistry({required AgentRegistry registry, IntentCallAuthorizationPolicy policy = const IntentCallAuthorizationPolicy.denyAll(), bool registerWebMcp = false, bool drainOnStart = true, bool drainOnResume = true, bool listenForDeepLinks = false, String? protocolScheme, IntentCallPendingReader? takePendingInvocations, Stream<IntentCallDrainTrigger>? wakeSignals, IntentCallEnvelopeCallback? onEnvelope, IntentCallResultCallback? onResult, IntentCallResultCallback? onDenied, IntentCallErrorCallback? onError})
factory

Properties

bridge IntentCallNativeBridge
final
drainOnStart bool
final
events Stream<IntentCallHostEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
onDenied IntentCallResultCallback?
final
onEnvelope IntentCallEnvelopeCallback?
final
onError IntentCallErrorCallback?
final
onResult IntentCallResultCallback?
final
registerWebMcp bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
takePendingInvocations IntentCallPendingReader
final

Methods

dispose() Future<void>
drainPendingInvocations() Future<List<AgentResult>>
execute(IntentCallInvocationEnvelope envelope, {IntentCallDrainTrigger trigger = IntentCallDrainTrigger.manual}) Future<AgentResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestDrain(IntentCallDrainTrigger trigger) Future<List<AgentResult>>
start() Future<List<AgentResult>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited